@@ -27,7 +27,12 @@ class Schlage:
         """
         path = Lock.request_path()
         response = self._auth.request("get", path, params={"archetype": "lock"})
-        return [Lock.from_json(self._auth, d) for d in response.json()]
+        locks = []
+        for lock_json in response.json():
+            lock = Lock.from_json(self._auth, lock_json)
+            lock.refresh_access_codes()
+            locks.append(lock)
+        return locks
 
     def users(self) -> list[User]:
         """Retrieves all users associated with this account's locks.
