@@ -1,17 +1,25 @@
-from unittest import mock
+from __future__ import annotations
+
+from typing import Any
+from unittest.mock import Mock, create_autospec
 
 from pytest import fixture
 
 from pyschlage.auth import Auth
+from pyschlage.code import AccessCode
+from pyschlage.device import Device
+from pyschlage.lock import Lock
+from pyschlage.log import LockLog
+from pyschlage.notification import ON_UNLOCK_ACTION, Notification
 
 
 @fixture
 def mock_auth():
-    yield mock.create_autospec(Auth, spec_set=True, user_id="<user-id>")
+    yield create_autospec(Auth, spec_set=True, user_id="<user-id>")
 
 
 @fixture
-def lock_users_json():
+def lock_users_json() -> list[dict]:
     return [
         {
             "consentRecords": [],
@@ -103,6 +111,23 @@ def wifi_lock_json(lock_users_json):
     }
 
 
+@fixture
+def wifi_lock(mock_auth: Mock, wifi_lock_json: dict, access_code: AccessCode) -> Lock:
+    lock = Lock.from_json(mock_auth, wifi_lock_json)
+    assert access_code.access_code_id is not None
+    lock.access_codes = {access_code.access_code_id: access_code}
+    return lock
+
+
+@fixture
+def wifi_device(mock_auth: Mock, wifi_lock_json: dict) -> Device:
+    return Device(
+        _auth=mock_auth,
+        device_id=wifi_lock_json["deviceId"],
+        device_type=wifi_lock_json["devicetypeId"],
+    )
+
+
 @fixture
 def wifi_lock_unavailable_json(wifi_lock_json):
     keep = ("modelName", "serialNumber", "macAddress", "SAT", "CAT")
@@ -170,11 +195,13 @@ def access_code_json():
     return {
         "accessCode": 123,
         "accesscodeId": "__access_code_uuid__",
+        "accessCodeLength": 4,
         "activationSecs": 0,
         "disabled": 0,
         "expirationSecs": 4294967295,
         "friendlyName": "Friendly name",
         "notification": 0,
+        "notificationEnabled": False,
         "schedule1": {
             "daysOfWeek": "7F",
             "endHour": 23,
@@ -186,7 +213,34 @@ def access_code_json():
 
 
 @fixture
-def log_json():
+def access_code(
+    mock_auth: Mock, wifi_device: Device, access_code_json: dict
+) -> AccessCode:
+    return AccessCode.from_json(mock_auth, wifi_device, access_code_json)
+
+
+@fixture
+def notification_json() -> dict[str, Any]:
+    return {
+        "notificationId": "<user-id>___access_code_uuid__",
+        "userId": "<user-id>",
+        "deviceId": "__wifi_uuid__",
+        "devicetypeId": "be489wifi",
+        "notificationDefinitionId": ON_UNLOCK_ACTION,
+        "filterValue": "Friendly name",
+        "active": True,
+        "createdAt": "2023-03-01T17:26:47.366Z",
+        "updatedAt": "2023-03-01T17:26:47.366Z",
+    }
+
+
+@fixture
+def notification(mock_auth: Auth, notification_json) -> Notification:
+    return Notification.from_json(mock_auth, notification_json)
+
+
+@fixture
+def log_json() -> dict[str, Any]:
     return {
         "createdAt": "2023-03-01T17:26:47.366Z",
         "deviceId": "__device_uuid__",
@@ -204,3 +258,8 @@ def log_json():
         "type": "DEVICE_LOG",
         "updatedAt": "2023-03-01T17:26:47.366Z",
     }
+
+
+@fixture
+def lock_log(log_json: dict[str, Any]) -> LockLog:
+    return LockLog.from_json(log_json)
